@@ -4,6 +4,7 @@
 # @Email  : 877362867@qq.com
 # @Date   : 2021/06/03 20:35
 
+import builtins
 from collections import Counter
 import datetime
 import inspect
@@ -156,6 +157,9 @@ def dprint(*args, **kwargs):
     """
     print(dformat(depth=3, **kwargs))
 
+# dprint会被注册进builtins，可以在任意地方直接使用
+setattr(builtins, 'dprint', dprint)
+
 
 class DPrint:
     """ 用来存储上下文相关变量，进行全局性地调试
